Hyuga - Yet Another Hy Language Server
======================================

[![PyPI version](https://badge.fury.io/py/hyuga.svg)](https://badge.fury.io/py/hyuga)

Forked from [hy-language-server](https://github.com/rinx/hy-language-server).

Verified-working Hy version: 0.24.0

This program is **experimental**. Do not use for production.

## Feature

- `textDocument/completion`
- `textDocument/hover`
- `textDocument/did{Open,Change}`

## Screenshots

![Hyuga sample movie](https://raw.githubusercontent.com/sakuraiyuta/hyuga/images/hyuga-image.gif)


## Install

TODO: implement

## license

MIT
